@@ -30,20 +30,24 @@ def test_cache_integrity(use_pkglist):
     arg = "--list=pkglist.json" if use_pkglist else "*"
 
     t.run(f"cache check-integrity {arg}", assert_error=True)
-    assert "pkg1/1.0: Integrity checked: ok" in t.out
-    assert "pkg1/1.0:da39a3ee5e6b4b0d3255bfef95601890afd80709: Integrity checked: ok" in t.out
-    assert "ERROR: pkg2/2.0:da39a3ee5e6b4b0d3255bfef95601890afd80709: Manifest mismatch" in t.out
-    assert "ERROR: pkg3/3.0:da39a3ee5e6b4b0d3255bfef95601890afd80709: Manifest mismatch" in t.out
-    assert "ERROR: pkg4/4.0:da39a3ee5e6b4b0d3255bfef95601890afd80709: Manifest mismatch" in t.out
+    assert "pkg1/1.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
+    assert "pkg1/1.0#4d670581ccb765839f2239cc8dff8fbd:da39a3ee5e6b4b0d3255bfef95601890afd80709" \
+           "#0ba8627bd47edc3a501e8f0eb9a79e5e: Integrity check: ok" in t.out
+    assert "pkg2/2.0#4d670581ccb765839f2239cc8dff8fbd:da39a3ee5e6b4b0d3255bfef95601890afd80709" \
+           "#0ba8627bd47edc3a501e8f0eb9a79e5e: ERROR: \nManifest mismatch" in t.out
+    assert "pkg3/3.0#4d670581ccb765839f2239cc8dff8fbd:da39a3ee5e6b4b0d3255bfef95601890afd80709" \
+           "#0ba8627bd47edc3a501e8f0eb9a79e5e: ERROR: \nManifest mismatch" in t.out
+    assert "pkg4/4.0#4d670581ccb765839f2239cc8dff8fbd:da39a3ee5e6b4b0d3255bfef95601890afd80709" \
+           "#0ba8627bd47edc3a501e8f0eb9a79e5e: ERROR: \nManifest mismatch" in t.out
 
     t.run("remove pkg2/2.0:da39a3ee5e6b4b0d3255bfef95601890afd80709 -c")
     t.run("remove pkg3/3.0:da39a3ee5e6b4b0d3255bfef95601890afd80709 -c")
     t.run("remove pkg4/4.0:da39a3ee5e6b4b0d3255bfef95601890afd80709 -c")
     t.run("cache check-integrity *")
-    assert "pkg1/1.0: Integrity checked: ok" in t.out
-    assert "pkg2/2.0: Integrity checked: ok" in t.out
-    assert "pkg3/3.0: Integrity checked: ok" in t.out
-    assert "pkg4/4.0: Integrity checked: ok" in t.out
+    assert "pkg1/1.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
+    assert "pkg2/2.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
+    assert "pkg3/3.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
+    assert "pkg4/4.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
 
 
 def test_cache_integrity_missing_recipe_manifest():
@@ -57,15 +61,16 @@ def test_cache_integrity_missing_recipe_manifest():
     t.run("create . --name pkg3 --version=3.0")
 
     t.run("cache check-integrity *", assert_error=True)
-    assert "pkg1/1.0: Integrity checked: ok" in t.out
-    assert "ERROR: pkg2/2.0#4d670581ccb765839f2239cc8dff8fbd: Manifest missing" in t.out
-    assert "pkg3/3.0: Integrity checked: ok" in t.out
+    assert "pkg1/1.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
+    assert "pkg2/2.0#4d670581ccb765839f2239cc8dff8fbd: ERROR: Manifest missing" in t.out
+    assert "pkg3/3.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
     assert "ERROR: There are corrupted artifacts, check the error logs" in t.out
 
     t.run("remove pkg2* -c")
     t.run("cache check-integrity *")
-    assert "pkg1/1.0:da39a3ee5e6b4b0d3255bfef95601890afd80709: Integrity checked: ok" in t.out
-    assert "pkg3/3.0: Integrity checked: ok" in t.out
+    assert "pkg1/1.0#4d670581ccb765839f2239cc8dff8fbd:da39a3ee5e6b4b0d3255bfef95601890afd80709" \
+           "#0ba8627bd47edc3a501e8f0eb9a79e5e: Integrity check: ok" in t.out
+    assert "pkg3/3.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
     assert "Integrity check: ok" in t.out
 
 
@@ -80,17 +85,17 @@ def test_cache_integrity_missing_package_manifest():
     t.run("create . --name pkg3 --version=3.0")
 
     t.run("cache check-integrity *", assert_error=True)
-    assert "pkg1/1.0: Integrity checked: ok" in t.out
-    assert "ERROR: pkg2/2.0#4d670581ccb765839f2239cc8dff8fbd" \
-           ":da39a3ee5e6b4b0d3255bfef95601890afd80709" \
-           "#0ba8627bd47edc3a501e8f0eb9a79e5e: Manifest missing" in t.out
-    assert "pkg3/3.0: Integrity checked: ok" in t.out
+    assert "pkg1/1.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
+    assert "pkg2/2.0#4d670581ccb765839f2239cc8dff8fbd:da39a3ee5e6b4b0d3255bfef95601890afd80709" \
+           "#0ba8627bd47edc3a501e8f0eb9a79e5e: ERROR: Manifest missing" in t.out
+    assert "pkg3/3.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
     assert "ERROR: There are corrupted artifacts, check the error logs" in t.out
 
     t.run("remove pkg2* -c")
     t.run("cache check-integrity *")
-    assert "pkg1/1.0:da39a3ee5e6b4b0d3255bfef95601890afd80709: Integrity checked: ok" in t.out
-    assert "pkg3/3.0: Integrity checked: ok" in t.out
+    assert "pkg1/1.0#4d670581ccb765839f2239cc8dff8fbd:da39a3ee5e6b4b0d3255bfef95601890afd80709" \
+           "#0ba8627bd47edc3a501e8f0eb9a79e5e: Integrity check: ok" in t.out
+    assert "pkg3/3.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
     assert "Integrity check: ok" in t.out
 
 
@@ -104,12 +109,26 @@ def test_cache_integrity_missing_package_conaninfo():
     os.remove(conaninfo)
 
     t.run("cache check-integrity *", assert_error=True)
-    assert "pkg1/1.0: Integrity checked: ok" in t.out
-    assert "ERROR: pkg2/2.0:da39a3ee5e6b4b0d3255bfef95601890afd80709: Manifest mismatch" in t.out
+    assert "pkg1/1.0#4d670581ccb765839f2239cc8dff8fbd: Integrity check: ok" in t.out
+    assert "pkg2/2.0#4d670581ccb765839f2239cc8dff8fbd:da39a3ee5e6b4b0d3255bfef95601890afd80709" \
+           "#0ba8627bd47edc3a501e8f0eb9a79e5e: ERROR: \nManifest mismatch" in t.out
 
     t.run("remove pkg2* -c")
     t.run("cache check-integrity *")
-    assert "pkg1/1.0:da39a3ee5e6b4b0d3255bfef95601890afd80709: Integrity checked: ok" in t.out
+    assert "pkg1/1.0#4d670581ccb765839f2239cc8dff8fbd:da39a3ee5e6b4b0d3255bfef95601890afd80709" \
+           "#0ba8627bd47edc3a501e8f0eb9a79e5e: Integrity check: ok" in t.out
+
+
+def test_cache_integrity_missing_package_file():
+    t = TestClient()
+    t.save({"conanfile.py": GenConanfile().with_package_file("myfile", "mycontents!")})
+    t.run("create . --name pkg --version 1.0")
+    layout = t.created_layout()
+    os.remove(os.path.join(layout.package(), "myfile"))
+
+    t.run("cache check-integrity *", assert_error=True)
+    assert "pkg/1.0#2f2609c8e5c87bf836c3fdaa6096b55d:da39a3ee5e6b4b0d3255bfef95601890afd80709" \
+           "#d950d0cd76f6bba62c8add9c68d1aeb3: ERROR: \nManifest mismatch" in t.out
 
 
 def test_cache_integrity_export_sources():
@@ -119,7 +138,7 @@ def test_cache_integrity_export_sources():
             "src/mysource.cpp": ""})
     t.run("create .")
     t.run("cache check-integrity *")
-    assert "pkg/0.1: Integrity checked: ok" in t.out
+    assert "pkg/0.1#ae07161b81ab07f7f1f746391668df0e: Integrity check: ok" in t.out
 
     # If we download, integrity should be ok
     # (it failed before, because the manifest is not complete)
@@ -127,4 +146,4 @@ def test_cache_integrity_export_sources():
     t.run("remove * -c")
     t.run("install --requires=pkg/0.1")
     t.run("cache check-integrity *")
-    assert "pkg/0.1: Integrity checked: ok" in t.out
+    assert "pkg/0.1#ae07161b81ab07f7f1f746391668df0e: Integrity check: ok" in t.out
