@@ -268,6 +268,15 @@ class TestPkgListMerge:
         c.run("pkglist merge -l mylist.json", assert_error=True)
         assert "ERROR: Package list file invalid JSON:" in c.out
 
+        # This can happen when using a graph JSON file instead of a package list file
+        c.save({"conanfile.py": GenConanfile("lib")})
+        c.run("create . --version=1.0 --format=json", redirect_stdout="out/graph.json")
+        c.run("pkglist merge -l out/graph.json", assert_error=True)
+        assert (
+            'ERROR: Expected a package list file but found a graph file. You can create a "package list" JSON file by running:'
+            in c.out
+        )
+        assert "conan list --graph graph.json --format=json > pkglist.json" in c.out
 
 class TestDownloadUpload:
     @pytest.fixture()
@@ -382,3 +391,59 @@ class TestListRemove:
         client.run(f"list *:* {remote}")
         assert "zli/1.0.0" in client.out
         assert "zlib/1.0.0@user/channel" in client.out
+
+
+class TestListGraphContext:
+
+    @pytest.mark.parametrize("context, refs, not_refs", [
+        ("build", ["cmake/1.0", "m4/1.0", "protobuf/1.0"], []),
+        ("build-only", ["cmake/1.0", "m4/1.0"], ["protobuf/1.0"]),
+        ("host", ["zlib/1.0", "protobuf/1.0"], []),
+        ("host-only", ["zlib/1.0"], ["protobuf/1.0"])
+    ])
+    def test_list_graph_context(self, context, refs, not_refs):
+        c = TestClient(default_server_user=True, light=True)
+        c.save({
+            "zlib/conanfile.py": GenConanfile("zlib", "1.0").with_settings("os"),
+            "cmake/conanfile.py": GenConanfile("cmake", "1.0").with_settings("os"),
+            "m4/conanfile.py": GenConanfile("m4", "1.0").with_settings("os"),
+            "protobuf/conanfile.py": GenConanfile("protobuf", "1.0").with_settings("os"),
+            "app/conanfile.py": GenConanfile("app", "1.0").with_settings("os")
+            .with_requires("zlib/1.0", "protobuf/1.0")
+            .with_tool_requires("cmake/1.0", "m4/1.0", "protobuf/1.0")})
+        c.run("create zlib")
+        c.run("create protobuf")
+        c.run("create cmake")
+        c.run("create m4")
+        c.run("create app --format=json", redirect_stdout="graph.json")
+        # Now, let's filter the pkgs
+        c.run(f"list --graph=graph.json --graph-context={context} --format=json",
+              redirect_stdout="pkglist.json")
+        content = json.loads(c.load("pkglist.json"))
+        for ref in refs:
+            assert content["Local Cache"][ref]["revisions"]
+        for ref in not_refs:
+            assert content["Local Cache"].get(ref) is None
+        # Let's upload all the packages
+        c.run(f"list --graph=graph.json --format=json", redirect_stdout="pkglist.json")
+        c.run("upload --list=pkglist.json -r=default")
+        c.run("remove * -c")
+        c.run("create app --format=json", redirect_stdout="graph.json")
+        # Now, let's filter the pkgs
+        c.run(f"list --graph=graph.json --graph-context={context} -r=default --format=json",
+              redirect_stdout="pkglist.json")
+        content = json.loads(c.load("pkglist.json"))
+        for ref in refs:
+            assert content["default"][ref]["revisions"]
+        for ref in not_refs:
+            assert content["default"].get(ref) is None
+
+    def test_graph_list(self):
+        tc = TestClient(light=True)
+        tc.save({"conanfile.py": GenConanfile("lib", "1.0")})
+
+        tc.run("graph info . -f json --build=never --no-remote --filter=context", redirect_stdout="graph_context.json")
+
+        tc.run("list --graph=graph_context.json --graph-context=build-only --format=json",
+               assert_error=True)
+        assert "Note that the graph file should not be filtered" in tc.out
