@@ -1,6 +1,6 @@
 import json
 import os
-import unittest
+import pytest
 from collections import OrderedDict
 
 from conan.test.assets.genconanfile import GenConanfile
@@ -8,9 +8,10 @@ from conan.test.utils.tools import TestClient, TestServer
 from conan.internal.util.files import load
 
 
-class RemoteServerTest(unittest.TestCase):
+class TestRemoteServer:
 
-    def setUp(self):
+    @pytest.fixture(autouse=True)
+    def setup(self):
         self.servers = OrderedDict()
         for i in range(3):
             test_server = TestServer()
@@ -29,61 +30,61 @@ class RemoteServerTest(unittest.TestCase):
 
     def test_basic(self):
         self.client.run("remote list")
-        self.assertIn("remote0: http://", self.client.out)
-        self.assertIn("remote1: http://", self.client.out)
-        self.assertIn("remote2: http://", self.client.out)
+        assert "remote0: http://" in self.client.out
+        assert "remote1: http://" in self.client.out
+        assert "remote2: http://" in self.client.out
 
         self.client.run("remote add origin https://myurl")
         self.client.run("remote list")
         lines = str(self.client.out).splitlines()
-        self.assertIn("origin: https://myurl", lines[3])
+        assert "origin: https://myurl" in lines[3]
 
         self.client.run("remote update origin --url https://2myurl")
         self.client.run("remote list")
-        self.assertIn("origin: https://2myurl", self.client.out)
+        assert "origin: https://2myurl" in self.client.out
 
         self.client.run("remote update remote0 --url https://remote0url")
         self.client.run("remote list")
         output = str(self.client.out)
-        self.assertIn("remote0: https://remote0url", output.splitlines()[0])
+        assert "remote0: https://remote0url" in output.splitlines()[0]
 
         self.client.run("remote remove remote0")
         self.client.run("remote list")
         output = str(self.client.out)
-        self.assertIn("remote1: http://", output.splitlines()[0])
+        assert "remote1: http://" in output.splitlines()[0]
 
     def test_remove_remote(self):
         self.client.run("remote list")
-        self.assertIn("remote0: http://", self.client.out)
-        self.assertIn("remote1: http://", self.client.out)
-        self.assertIn("remote2: http://", self.client.out)
+        assert "remote0: http://" in self.client.out
+        assert "remote1: http://" in self.client.out
+        assert "remote2: http://" in self.client.out
         self.client.run("remote remove remote1")
         self.client.run("remote list")
-        self.assertNotIn("remote1", self.client.out)
-        self.assertIn("remote0", self.client.out)
-        self.assertIn("remote2", self.client.out)
+        assert "remote1" not in self.client.out
+        assert "remote0" in self.client.out
+        assert "remote2" in self.client.out
         self.client.run("remote remove remote2")
         self.client.run("remote list")
-        self.assertNotIn("remote1", self.client.out)
-        self.assertIn("remote0", self.client.out)
-        self.assertNotIn("remote2", self.client.out)
+        assert "remote1" not in self.client.out
+        assert "remote0" in self.client.out
+        assert "remote2" not in self.client.out
 
     def test_remove_remote_all(self):
         self.client.run("remote list")
-        self.assertIn("remote0: http://", self.client.out)
-        self.assertIn("remote1: http://", self.client.out)
-        self.assertIn("remote2: http://", self.client.out)
+        assert "remote0: http://" in self.client.out
+        assert "remote1: http://" in self.client.out
+        assert "remote2: http://" in self.client.out
         self.client.run("remote remove *")
         self.client.run("remote list")
-        self.assertNotIn("remote1", self.client.out)
-        self.assertNotIn("remote0", self.client.out)
-        self.assertNotIn("remote2", self.client.out)
+        assert "remote1" not in self.client.out
+        assert "remote0" not in self.client.out
+        assert "remote2" not in self.client.out
 
     def test_remove_remote_no_user(self):
         self.client.save({"conanfile.py": GenConanfile()})
         self.client.run("remote remove remote0")
         self.client.run("remote list")
-        self.assertNotIn("remote0", self.client.out)
+        assert "remote0" not in self.client.out
 
     def test_insert(self):
         self.client.run("remote add origin https://myurl --index", assert_error=True)
@@ -92,57 +93,57 @@ class RemoteServerTest(unittest.TestCase):
         self.client.run("remote add origin2 https://myurl2 --index=0")
         self.client.run("remote list")
         lines = str(self.client.out).splitlines()
-        self.assertIn("origin2: https://myurl2", lines[0])
-        self.assertIn("origin: https://myurl", lines[1])
+        assert "origin2: https://myurl2" in lines[0]
+        assert "origin: https://myurl" in lines[1]
 
         self.client.run("remote add origin3 https://myurl3 --index=1")
         self.client.run("remote list")
         lines = str(self.client.out).splitlines()
-        self.assertIn("origin2: https://myurl2", lines[0])
-        self.assertIn("origin3: https://myurl3", lines[1])
-        self.assertIn("origin: https://myurl", lines[2])
+        assert "origin2: https://myurl2" in lines[0]
+        assert "origin3: https://myurl3" in lines[1]
+        assert "origin: https://myurl" in lines[2]
 
     def test_duplicated_error(self):
         """ check remote name are not duplicated
         """
         self.client.run("remote add remote1 http://otherurl", assert_error=True)
-        self.assertIn("ERROR: Remote 'remote1' already exists in remotes (use --force to continue)",
-                      self.client.out)
+        assert "ERROR: Remote 'remote1' already exists in remotes (use --force to continue)" \
+                      in self.client.out
 
         self.client.run("remote list")
         assert "otherurl" not in self.client.out
         self.client.run("remote add remote1 http://otherurl --force")
-        self.assertIn("WARN: Remote 'remote1' already exists in remotes", self.client.out)
+        assert "WARN: Remote 'remote1' already exists in remotes" in self.client.out
 
         self.client.run("remote list")
         assert "remote1: http://otherurl" in self.client.out
 
     def test_missing_subarguments(self):
         self.client.run("remote", assert_error=True)
-        self.assertIn("ERROR: Exiting with code: 2", self.client.out)
+        assert "ERROR: Exiting with code: 2" in self.client.out
 
     def test_invalid_url(self):
         self.client.run("remote add foobar foobar.com")
-        self.assertIn("WARN: The URL 'foobar.com' is invalid. It must contain scheme and hostname.",
-                      self.client.out)
+        assert "WARN: The URL 'foobar.com' is invalid. It must contain scheme and hostname." \
+                      in self.client.out
         self.client.run("remote list")
-        self.assertIn("foobar.com", self.client.out)
+        assert "foobar.com" in self.client.out
 
         self.client.run("remote update foobar --url pepe.org")
-        self.assertIn("WARN: The URL 'pepe.org' is invalid. It must contain scheme and hostname.",
-                      self.client.out)
+        assert "WARN: The URL 'pepe.org' is invalid. It must contain scheme and hostname." \
+                      in self.client.out
         self.client.run("remote list")
-        self.assertIn("pepe.org", self.client.out)
+        assert "pepe.org" in self.client.out
 
     def test_errors(self):
         self.client.run("remote update origin --url http://foo.com", assert_error=True)
-        self.assertIn("ERROR: Remote 'origin' doesn't exist", self.client.out)
+        assert "ERROR: Remote 'origin' doesn't exist" in self.client.out
 
         self.client.run("remote remove origin", assert_error=True)
-        self.assertIn("ERROR: Remote 'origin' can't be found or is disabled", self.client.out)
+        assert "ERROR: Remote 'origin' can't be found or is disabled" in self.client.out
 
 
-class RemoteModificationTest(unittest.TestCase):
+class TestRemoteModification:
     def test_rename(self):
         client = TestClient(light=True)
         client.save({"conanfile.py": GenConanfile()})
@@ -153,13 +154,13 @@ class RemoteModificationTest(unittest.TestCase):
         client.run("remote rename r2 mynewr2")
         client.run("remote list")
         lines = str(client.out).splitlines()
-        self.assertIn("r1: https://r1", lines[0])
-        self.assertIn("mynewr2: https://r2", lines[1])
-        self.assertIn("r3: https://r3", lines[2])
+        assert "r1: https://r1" in lines[0]
+        assert "mynewr2: https://r2" in lines[1]
+        assert "r3: https://r3" in lines[2]
 
         # Rename to an existing one
         client.run("remote rename mynewr2 r1", assert_error=True)
-        self.assertIn("Remote 'r1' already exists", client.out)
+        assert "Remote 'r1' already exists" in client.out
 
     def test_update_insert(self):
         client = TestClient(light=True)
@@ -170,17 +171,17 @@ class RemoteModificationTest(unittest.TestCase):
         client.run("remote update r2 --url https://r2new --index=0")
         client.run("remote list")
         lines = str(client.out).splitlines()
-        self.assertIn("r2: https://r2new", lines[0])
-        self.assertIn("r1: https://r1", lines[1])
-        self.assertIn("r3: https://r3", lines[2])
+        assert "r2: https://r2new" in lines[0]
+        assert "r1: https://r1" in lines[1]
+        assert "r3: https://r3" in lines[2]
 
         client.run("remote update r2 --url https://r2new2")
         client.run("remote update r2 --index=2")
         client.run("remote list")
         lines = str(client.out).splitlines()
-        self.assertIn("r1: https://r1", lines[0])
-        self.assertIn("r3: https://r3", lines[1])
-        self.assertIn("r2: https://r2new2", lines[2])
+        assert "r1: https://r1" in lines[0]
+        assert "r3: https://r3" in lines[1]
+        assert "r2: https://r2new2" in lines[2]
 
     def test_update_insert_same_url(self):
         # https://github.com/conan-io/conan/issues/5107
@@ -191,8 +192,8 @@ class RemoteModificationTest(unittest.TestCase):
         client.run("remote update r2 --url https://r2")
         client.run("remote update r2 --index 0")
         client.run("remote list")
-        self.assertLess(str(client.out).find("r2"), str(client.out).find("r1"))
-        self.assertLess(str(client.out).find("r1"), str(client.out).find("r3"))
+        assert str(client.out).find("r2") < str(client.out).find("r1")
+        assert str(client.out).find("r1") < str(client.out).find("r3")
 
     def test_verify_ssl(self):
         client = TestClient(light=True)
@@ -202,17 +203,17 @@ class RemoteModificationTest(unittest.TestCase):
 
         registry = load(client.paths.remotes_path)
         data = json.loads(registry)
-        self.assertEqual(data["remotes"][0]["name"], "my-remote")
-        self.assertEqual(data["remotes"][0]["url"], "http://someurl")
-        self.assertEqual(data["remotes"][0]["verify_ssl"], True)
+        assert data["remotes"][0]["name"] == "my-remote"
+        assert data["remotes"][0]["url"] == "http://someurl"
+        assert data["remotes"][0]["verify_ssl"] == True
 
-        self.assertEqual(data["remotes"][1]["name"], "my-remote2")
-        self.assertEqual(data["remotes"][1]["url"], "http://someurl2")
-        self.assertEqual(data["remotes"][1]["verify_ssl"], False)
+        assert data["remotes"][1]["name"] == "my-remote2"
+        assert data["remotes"][1]["url"] == "http://someurl2"
+        assert data["remotes"][1]["verify_ssl"] == False
 
-        self.assertEqual(data["remotes"][2]["name"], "my-remote3")
-        self.assertEqual(data["remotes"][2]["url"], "http://someurl3")
-        self.assertEqual(data["remotes"][2]["verify_ssl"], True)
+        assert data["remotes"][2]["name"] == "my-remote3"
+        assert data["remotes"][2]["url"] == "http://someurl3"
+        assert data["remotes"][2]["verify_ssl"] == True
 
     def test_remote_disable(self):
         client = TestClient(light=True)
@@ -228,12 +229,12 @@ class RemoteModificationTest(unittest.TestCase):
         assert "Enabled: False" in client.out
         registry = load(client.paths.remotes_path)
         data = json.loads(registry)
-        self.assertEqual(data["remotes"][0]["name"], "my-remote0")
-        self.assertEqual(data["remotes"][0]["url"], "http://someurl0")
-        self.assertEqual(data["remotes"][0]["disabled"], True)
-        self.assertEqual(data["remotes"][3]["name"], "my-remote3")
-        self.assertEqual(data["remotes"][3]["url"], "http://someurl3")
-        self.assertEqual(data["remotes"][3]["disabled"], True)
+        assert data["remotes"][0]["name"] == "my-remote0"
+        assert data["remotes"][0]["url"] == "http://someurl0"
+        assert data["remotes"][0]["disabled"] == True
+        assert data["remotes"][3]["name"] == "my-remote3"
+        assert data["remotes"][3]["url"] == "http://someurl3"
+        assert data["remotes"][3]["disabled"] == True
 
         # check that they are still listed, as disabled
         client.run("remote list")
@@ -245,7 +246,7 @@ class RemoteModificationTest(unittest.TestCase):
         registry = load(client.paths.remotes_path)
         data = json.loads(registry)
         for remote in data["remotes"]:
-            self.assertEqual(remote["disabled"], True)
+            assert remote["disabled"] == True
 
         data = json.loads(client.stdout)
         for remote in data:
@@ -255,7 +256,7 @@ class RemoteModificationTest(unittest.TestCase):
         registry = load(client.paths.remotes_path)
         data = json.loads(registry)
         for remote in data["remotes"]:
-            self.assertNotIn("disabled", remote)
+            assert "disabled" not in remote
         assert "my-remote0" in client.out
         assert "my-remote1" in client.out
         assert "my-remote2" in client.out
@@ -267,10 +268,10 @@ class RemoteModificationTest(unittest.TestCase):
 
         client.run("remote disable invalid_remote", assert_error=True)
         msg = "ERROR: Remote 'invalid_remote' can't be found or is disabled"
-        self.assertIn(msg, client.out)
+        assert msg in client.out
 
         client.run("remote enable invalid_remote", assert_error=True)
-        self.assertIn(msg, client.out)
+        assert msg in client.out
 
         client.run("remote disable invalid_wildcard_*")
 
@@ -291,9 +292,9 @@ class RemoteModificationTest(unittest.TestCase):
         client = TestClient(light=True)
         client.run("remote add my-remote http://someurl some_invalid_option=foo", assert_error=True)
 
-        self.assertIn("unrecognized arguments: some_invalid_option=foo", client.out)
+        assert "unrecognized arguments: some_invalid_option=foo" in client.out
         data = json.loads(load(client.paths.remotes_path))
-        self.assertEqual(data["remotes"], [])
+        assert data["remotes"] == []
 
 
 def test_add_duplicated_url():
