@@ -1,7 +1,6 @@
 import os
 import re
 import textwrap
-import unittest
 from collections import OrderedDict
 
 import pytest
@@ -9,10 +8,9 @@ import pytest
 from conan.internal.paths import CONANFILE
 from conan.test.assets.genconanfile import GenConanfile
 from conan.test.utils.tools import TestClient, TestServer
-from conan.internal.util.files import save
 
 
-class SourceTest(unittest.TestCase):
+class TestSource:
 
     def test_local_flow_patch(self):
         # https://github.com/conan-io/conan/issues/2327
@@ -40,14 +38,14 @@ class TestexportConan(ConanFile):
                      "patch.patch": "mypatch",
                      "mypython.py": "mypython"})
         client.run("source .")
-        self.assertIn("conanfile.py (test/0.1): PATCH: mypatch", client.out)
-        self.assertIn("conanfile.py (test/0.1): HEADER: my hello header!", client.out)
-        self.assertIn("conanfile.py (test/0.1): PYTHON: mypython", client.out)
+        assert "conanfile.py (test/0.1): PATCH: mypatch" in client.out
+        assert "conanfile.py (test/0.1): HEADER: my hello header!" in client.out
+        assert "conanfile.py (test/0.1): PYTHON: mypython" in client.out
 
         client.run("create . ")
-        self.assertIn("test/0.1: PATCH: mypatch", client.out)
-        self.assertIn("test/0.1: HEADER: my hello header!", client.out)
-        self.assertIn("test/0.1: PYTHON: mypython", client.out)
+        assert "test/0.1: PATCH: mypatch" in client.out
+        assert "test/0.1: HEADER: my hello header!" in client.out
+        assert "test/0.1: PYTHON: mypython" in client.out
 
     def test_apply_patch(self):
         # https://github.com/conan-io/conan/issues/2327
@@ -66,11 +64,11 @@ class Pkg(ConanFile):
         client.save({"conanfile.py": conanfile,
                      "mypatch": "this is my patch"})
         client.run("source .")
-        self.assertIn("PATCH: this is my patch", client.out)
+        assert "PATCH: this is my patch" in client.out
         client.run("source .")
-        self.assertIn("PATCH: this is my patch", client.out)
+        assert "PATCH: this is my patch" in client.out
         client.run("create . --name=pkg --version=0.1 --user=user --channel=testing")
-        self.assertIn("PATCH: this is my patch", client.out)
+        assert "PATCH: this is my patch" in client.out
 
     def test_source_warning_os_build(self):
         # https://github.com/conan-io/conan/issues/2368
@@ -81,7 +79,7 @@ class ConanLib(ConanFile):
         client = TestClient(light=True)
         client.save({CONANFILE: conanfile})
         client.run("source .")
-        self.assertNotIn("This package defines both 'os' and 'os_build'", client.out)
+        assert "This package defines both 'os' and 'os_build'" not in client.out
 
     def test_source_with_path_errors(self):
         client = TestClient(light=True)
@@ -89,10 +87,8 @@ class ConanLib(ConanFile):
 
         # Path with conanfile.txt
         client.run("source conanfile.txt", assert_error=True)
-        self.assertIn(
-            "A conanfile.py is needed, %s is not acceptable"
-            % os.path.join(client.current_folder, "conanfile.txt"),
-            client.out)
+        assert "A conanfile.py is needed, %s is not acceptable" \
+                      % os.path.join(client.current_folder, "conanfile.txt") in client.out
 
     def test_source_local_cwd(self):
         conanfile = '''
@@ -112,8 +108,8 @@ class ConanLib(ConanFile):
 
         client.run("install .")
         client.run("source .")
-        self.assertIn("conanfile.py (hello/0.1): Calling source()", client.out)
-        self.assertIn("conanfile.py (hello/0.1): cwd=>%s" % client.current_folder, client.out)
+        assert "conanfile.py (hello/0.1): Calling source()" in client.out
+        assert "conanfile.py (hello/0.1): cwd=>%s" % client.current_folder in client.out
 
     def test_local_source(self):
         conanfile = '''
@@ -132,15 +128,48 @@ class ConanLib(ConanFile):
         client.save({CONANFILE: conanfile})
 
         client.run("source .", assert_error=True)
-        self.assertIn("conanfile.py: Running source!", client.out)
-        self.assertIn("ERROR: conanfile.py: Error in source() method, line 9", client.out)
+        assert "conanfile.py: Running source!" in client.out
+        assert "ERROR: conanfile.py: Error in source() method, line 9" in client.out
 
         # Fix the error and repeat
         client.save({CONANFILE: conanfile.replace("err", "")})
         client.run("source .")
-        self.assertIn("conanfile.py: Calling source() in", client.out)
-        self.assertIn("conanfile.py: Running source!", client.out)
-        self.assertEqual("Hello World", client.load("file1.txt"))
+        assert "conanfile.py: Calling source() in" in client.out
+        assert "conanfile.py: Running source!" in client.out
+        assert "Hello World" == client.load("file1.txt")
+
+    def test_local_source_layout_root(self):
+        # Ensure that if a root folder is specified Conan source method
+        # uses it. This is especially important when running with
+        # no_copy_source where both the build()  and source() methods
+        # need to reference source_folder (so the value must be the
+        # same in both methods)
+        conanfile = textwrap.dedent('''
+            from conan import ConanFile
+            from conan.tools.files import save, load
+
+            class ConanLib(ConanFile):
+
+                def layout(self):
+                    self.folders.root = ".."
+                    self.folders.source = "src"
+
+                def source(self):
+                    self.output.info(f"In the source() method the Source folder is: {self.source_folder}")
+                    save(self, "source_file.c", "conent")
+
+                def build(self):
+                    self.output.info(f"In the build() method the Source folder is: {self.source_folder}")
+                    load(self, f"{self.source_folder}/source_file.c")
+            ''')
+        client = TestClient(light=True)
+        client.save({CONANFILE: conanfile})
+
+        client.run("source .")
+        # The build method will fail if source() and build() don't
+        # both use the correct source_folder
+        client.run("build .")
+        assert "conanfile.py: Calling build()" in client.out  # doesn't fail
 
     def test_retrieve_exports_sources(self):
         # For Conan 2.0 if we install a package from a remote and we want to upload to other
@@ -166,7 +195,7 @@ class ConanLib(ConanFile):
         # download the sources from server0
         client.run("install --requires=hello/0.1@ -r server0")
         client.run("upload hello/0.1 -r server1")
-        self.assertIn("Sources downloaded from 'server0'", client.out)
+        assert "Sources downloaded from 'server0'" in client.out
 
         # install from server1 that has the sources, upload to server1
         # Will not download sources, revision already in server
@@ -174,13 +203,13 @@ class ConanLib(ConanFile):
         client.run("install --requires=hello/0.1@ -r server1")
         client.run("upload hello/0.1 -r server1")
         assert f"'hello/0.1#{rrev}' already in server, skipping upload" in client.out
-        self.assertNotIn("Sources downloaded from 'server0'", client.out)
+        assert "Sources downloaded from 'server0'" not in client.out
 
         # install from server0 and build
         # download sources from server0
         client.run("remove * -c")
         client.run("install --requires=hello/0.1@ -r server0 --build='*'")
-        self.assertIn("Sources downloaded from 'server0'", client.out)
+        assert "Sources downloaded from 'server0'" in client.out
 
     def test_source_method_called_once(self):
         """
@@ -246,7 +275,7 @@ class TestSourceWithoutDefaultProfile:
     def client(self):
         c = TestClient()
         # The ``source()`` should still receive necessary configuration
-        save(c.paths.new_config_path, "tools.files.download:retry=MYCACHE")
+        c.save_home({"global.conf": "tools.files.download:retry=MYCACHE"})
         # Make sure we don't have default profile
         os.remove(os.path.join(c.cache_folder, "profiles", "default"))
         return c
