@@ -93,6 +93,7 @@ class TestUser:
         servers = {"default": test_server}
         client = TestClient(servers=servers, inputs=["lasote", "mypass"])
         client.run(r'remote login default lasote -p="my \"password"')
+        assert "Connecting to remote" not in client.out
         assert "Changed user of remote 'default' from 'None' (anonymous) to 'lasote'" in client.out
         client.run('remote logout default')
         client.run(r'remote login default lasote -p "my \"password"')
@@ -363,7 +364,7 @@ class TestRemoteAuth:
         c = TestClient(servers=servers, inputs=["lasote", "mypass", "danimtb", "passpass",
                                                 "lasote", "mypass"])
 
-        with patch("conans.client.rest.rest_client_v2.RestV2Methods.check_credentials") as check_credentials_mock:
+        with patch("conan.internal.rest.rest_client_v2.RestV2Methods.check_credentials") as check_credentials_mock:
             c.run("remote auth --force *")
             check_credentials_mock.assert_called_with(True)
 
@@ -374,7 +375,7 @@ class TestRemoteAuth:
         c = TestClient(servers=servers, inputs=["lasote", "mypass", "danimtb", "passpass",
                                                 "lasote", "mypass"])
 
-        with patch("conans.client.rest.rest_client_v2.RestV2Methods.check_credentials") as check_credentials_mock:
+        with patch("conan.internal.rest.rest_client_v2.RestV2Methods.check_credentials") as check_credentials_mock:
             c.run("remote auth *")
             check_credentials_mock.assert_called_with(False)
 
