@@ -3,7 +3,6 @@ import os
 import platform
 import stat
 import textwrap
-import unittest
 from collections import OrderedDict
 
 import pytest
@@ -12,7 +11,6 @@ from requests import Response
 
 from conan.errors import ConanException
 from conan.api.model import PkgReference
-from conan.api.model import RecipeReference
 from conan.internal.api.uploader import gzopen_without_timestamps
 from conan.internal.paths import EXPORT_SOURCES_TGZ_NAME, PACKAGE_TGZ_NAME
 from conan.test.utils.tools import NO_SETTINGS_PACKAGE_ID, TestClient, TestServer, \
@@ -32,11 +30,11 @@ class MyPkg(ConanFile):
 """
 
 
-class UploadTest(unittest.TestCase):
+class TestUpload:
 
     @pytest.mark.artifactory_ready
     def test_upload_dirty(self):
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         client.save({"conanfile.py": GenConanfile("hello", "0.1")})
         client.run("create .")
 
@@ -55,7 +53,7 @@ class UploadTest(unittest.TestCase):
 
     @pytest.mark.artifactory_ready
     def test_upload_force(self):
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         conanfile_ = textwrap.dedent("""
             from conan import ConanFile
             from conan.tools.files import copy
@@ -101,7 +99,7 @@ class UploadTest(unittest.TestCase):
 
     @pytest.mark.artifactory_ready
     def test_pattern_upload(self):
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         client.save({"conanfile.py": conanfile})
         client.run("create . --user=user --channel=testing")
         client.run("upload hello0/*@user/testing --confirm -r default")
@@ -109,45 +107,44 @@ class UploadTest(unittest.TestCase):
         assert "Uploading package 'hello0/1.2.1@" in client.out
 
     def test_pattern_upload_no_recipes(self):
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         client.save({"conanfile.py": conanfile})
         client.run("upload bogus/*@dummy/testing --confirm -r default", assert_error=True)
-        self.assertIn("No recipes found matching pattern 'bogus/*@dummy/testing'", client.out)
+        assert "No recipes found matching pattern 'bogus/*@dummy/testing'" in client.out
 
     def test_broken_sources_tgz(self):
         # https://github.com/conan-io/conan/issues/2854
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         client.save({"conanfile.py": conanfile,
                      "source.h": "my source"})
         client.run("create . --user=user --channel=testing")
         layout = client.exported_layout()
 
-        def gzopen_patched(name, mode="r", fileobj=None, **kwargs):
+        def gzopen_patched(name, mode="r", fileobj=None, **kwargs):  # noqa
             raise ConanException("Error gzopen %s" % name)
         with patch('conan.internal.api.uploader.gzopen_without_timestamps', new=gzopen_patched):
             client.run("upload * --confirm -r default --only-recipe",
                        assert_error=True)
-            self.assertIn("Error gzopen conan_sources.tgz", client.out)
+            assert "Error gzopen conan_sources.tgz" in client.out
 
             export_download_folder = layout.download_export()
 
             tgz = os.path.join(export_download_folder, EXPORT_SOURCES_TGZ_NAME)
-            self.assertTrue(os.path.exists(tgz))
-            self.assertTrue(is_dirty(tgz))
+            assert os.path.exists(tgz)
+            assert is_dirty(tgz)
 
         client.run("upload * --confirm -r default --only-recipe")
-        self.assertIn("Removing conan_sources.tgz, marked as dirty", client.out)
-        self.assertTrue(os.path.exists(tgz))
-        self.assertFalse(is_dirty(tgz))
+        assert "Removing conan_sources.tgz, marked as dirty" in client.out
+        assert os.path.exists(tgz)
+        assert not is_dirty(tgz)
 
     def test_broken_package_tgz(self):
         # https://github.com/conan-io/conan/issues/2854
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         client.save({"conanfile.py": conanfile,
                      "source.h": "my source"})
         client.run("create . --user=user --channel=testing")
-        pref = client.get_latest_package_reference(RecipeReference.loads("hello0/1.2.1@user/testing"),
-                                                   NO_SETTINGS_PACKAGE_ID)
+        pref = client.created_layout().reference
 
         def gzopen_patched(name, fileobj, compresslevel=None):  # noqa
             if name == PACKAGE_TGZ_NAME:
@@ -155,35 +152,38 @@ class UploadTest(unittest.TestCase):
             return gzopen_without_timestamps(name, fileobj)
         with patch('conan.internal.api.uploader.gzopen_without_timestamps', new=gzopen_patched):
             client.run("upload * --confirm -r default", assert_error=True)
-            self.assertIn("Error gzopen conan_package.tgz", client.out)
+            assert "Error gzopen conan_package.tgz" in client.out
 
             download_folder = client.get_latest_pkg_layout(pref).download_package()
             tgz = os.path.join(download_folder, PACKAGE_TGZ_NAME)
-            self.assertTrue(os.path.exists(tgz))
-            self.assertTrue(is_dirty(tgz))
+            assert os.path.exists(tgz)
+            assert is_dirty(tgz)
 
         client.run("upload * --confirm -r default")
-        self.assertIn("WARN: Removing conan_package.tgz, marked as dirty", client.out)
-        self.assertTrue(os.path.exists(tgz))
-        self.assertFalse(is_dirty(tgz))
+        assert "WARN: Removing conan_package.tgz, marked as dirty" in client.out
+        assert os.path.exists(tgz)
+        assert not is_dirty(tgz)
 
     def test_corrupt_upload(self):
-        client = TestClient(default_server_user=True)
+        c = TestClient(default_server_user=True, light=True)
 
-        client.save({"conanfile.py": conanfile,
-                     "include/hello.h": ""})
-        client.run("create . --user=frodo --channel=stable")
-        package_folder = client.created_layout().package()
+        c.save({"conanfile.py": conanfile,
+                "include/hello.h": ""})
+        c.run("create . --user=frodo --channel=stable")
+        package_folder = c.created_layout().package()
         save(os.path.join(package_folder, "added.txt"), "")
         os.remove(os.path.join(package_folder, "include/hello.h"))
-        client.run("upload hello0/1.2.1@frodo/stable --check -r default", assert_error=True)
-        self.assertIn("ERROR:     'include/hello.h'", client.out)
-        self.assertIn("ERROR:     'added.txt'", client.out)
-        self.assertIn("ERROR: There are corrupted artifacts, check the error logs", client.out)
+        c.run("upload hello0/1.2.1@frodo/stable --check -r default", assert_error=True)
+        assert ("hello0/1.2.1@frodo/stable#3afd661184b94bdac7fb2057e7bd9baa"
+                ":da39a3ee5e6b4b0d3255bfef95601890afd80709"
+                "#e70e86439dec07a0d5d3414648b0b16c: ERROR") in c.out
+        assert "include/hello.h (manifest: d41d8cd98f00b204e9800998ecf8427e, file: None)" in c.out
+        assert "added.txt (manifest: None, file: d41d8cd98f00b204e9800998ecf8427e)" in c.out
+        assert "ERROR: There are corrupted artifacts, check the error logs" in c.out
 
     @pytest.mark.artifactory_ready
     def test_upload_modified_recipe(self):
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
 
         client.save({"conanfile.py": conanfile,
                      "hello.cpp": "int i=0"})
@@ -206,12 +206,11 @@ class UploadTest(unittest.TestCase):
         # first client tries to upload again
         # The client tries to upload exactly the same revision already uploaded, so no changes
         client.run("upload hello0/1.2.1@frodo/stable -r default")
-        self.assertIn(f"'hello0/1.2.1@frodo/stable#{rrev}' already "
-                      "in server, skipping upload", client.out)
+        assert f"'hello0/1.2.1@frodo/stable#{rrev}' already in server, skipping upload" in client.out
 
     @pytest.mark.artifactory_ready
     def test_upload_unmodified_recipe(self):
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         files = {"conanfile.py": GenConanfile("hello0", "1.2.1")}
         client.save(files)
         client.run("export . --user=frodo --channel=stable")
@@ -227,48 +226,39 @@ class UploadTest(unittest.TestCase):
         manifest.time += 10
         manifest.save(layout.export())
         client2.run("upload hello0/1.2.1@frodo/stable -r default")
-        self.assertIn(f"Recipe 'hello0/1.2.1@frodo/stable#761f54e34d59deb172d6078add7050a7' already "
-                      "in server, skipping upload", client2.out)
+        assert (f"Recipe 'hello0/1.2.1@frodo/stable#761f54e34d59deb172d6078add7050a7' already "
+                f"in server, skipping upload") in client2.out
 
         # first client tries to upload again
         client.run("upload hello0/1.2.1@frodo/stable -r default")
-        self.assertIn(f"Recipe 'hello0/1.2.1@frodo/stable#{rrev}' "
-                      "already in server, skipping upload", client.out)
+        assert (f"Recipe 'hello0/1.2.1@frodo/stable#{rrev}' "
+                f"already in server, skipping upload") in client.out
 
     @pytest.mark.artifactory_ready
     def test_upload_unmodified_package(self):
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
 
         client.save({"conanfile.py": conanfile,
                      "hello.cpp": ""})
-        ref = RecipeReference.loads("hello0/1.2.1@frodo/stable")
         client.run("create . --user=frodo --channel=stable")
+        prev1 = client.created_layout().reference
         client.run("upload hello0/1.2.1@frodo/stable -r default")
 
         client2 = TestClient(servers=client.servers, inputs=["admin", "password"])
         client2.save({"conanfile.py": conanfile,
                       "hello.cpp": ""})
         client2.run("create . --user=frodo --channel=stable")
-        refs = client2.cache.get_latest_recipe_reference(ref)
-        pkgs = client2.cache.get_package_references(refs)
-        prev2 = client2.cache.get_latest_package_reference(pkgs[0])
+        prev2 = client2.created_layout().reference
         client2.run("upload hello0/1.2.1@frodo/stable -r default")
-        self.assertIn(f"'{repr(prev2.ref)}' already "
-                      "in server, skipping upload", client2.out)
-        self.assertNotIn("Uploaded conan recipe 'hello0/1.2.1@frodo/stable' to 'default'",
-                         client2.out)
-        self.assertIn(f"'{prev2.repr_notime()}' already in server, skipping upload", client2.out)
+        assert f"'{repr(prev2.ref)}' already in server, skipping upload" in client2.out
+        assert "Uploaded conan recipe 'hello0/1.2.1@frodo/stable' to 'default'" not in client2.out
+        assert f"'{prev2.repr_notime()}' already in server, skipping upload" in client2.out
 
         # first client tries to upload again
-        refs = client.cache.get_latest_recipe_reference(ref)
-        pkgs = client.cache.get_package_references(refs)
-        prev1 = client.cache.get_latest_package_reference(pkgs[0])
         client.run("upload hello0/1.2.1@frodo/stable -r default")
-        self.assertIn(f"'{repr(prev1.ref)}' already "
-                      "in server, skipping upload", client.out)
-        self.assertNotIn("Uploaded conan recipe 'hello0/1.2.1@frodo/stable' to 'default'",
-                         client.out)
-        self.assertIn(f"'{prev1.repr_notime()}' already in server, skipping upload", client2.out)
+        assert f"'{repr(prev1.ref)}' already in server, skipping upload" in client.out
+        assert "Uploaded conan recipe 'hello0/1.2.1@frodo/stable' to 'default'" not in client.out
+        assert f"'{prev1.repr_notime()}' already in server, skipping upload" in client2.out
 
     def test_upload_no_overwrite_all(self):
         conanfile_new = GenConanfile("hello", "1.0").\
@@ -276,28 +266,25 @@ class UploadTest(unittest.TestCase):
             with_exports_sources(["*"]).\
             with_package('copy(self, "*", self.source_folder, self.package_folder)')
 
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         client.save({"conanfile.py": conanfile_new,
                      "hello.h": ""})
         client.run("create . --user=frodo --channel=stable")
+        prev1 = client.created_layout().reference
         # First time upload
         client.run("upload hello/1.0@frodo/stable -r default")
-        self.assertNotIn("Forbidden overwrite", client.out)
-        self.assertIn("Uploading recipe 'hello/1.0@frodo/stable", client.out)
+        assert "Forbidden overwrite" not in client.out
+        assert "Uploading recipe 'hello/1.0@frodo/stable" in client.out
 
         # CASE: Upload again
         client.run("upload hello/1.0@frodo/stable -r default")
-        refs = client.cache.get_latest_recipe_reference(RecipeReference.loads("hello/1.0@frodo/stable"))
-        pkgs = client.cache.get_package_references(refs)
-        prev1 = client.cache.get_latest_package_reference(pkgs[0])
-        self.assertIn(f"'{repr(prev1.ref)}' already "
-                      "in server, skipping upload", client.out)
-        self.assertIn(f"'{prev1.repr_notime()}' already in server, skipping upload", client.out)
+        assert f"'{repr(prev1.ref)}' already in server, skipping upload" in client.out
+        assert f"'{prev1.repr_notime()}' already in server, skipping upload" in client.out
 
     def test_skip_upload(self):
         """ Check that the option --skip does not upload anything
         """
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         client.save({"conanfile.py": GenConanfile("hello0", "1.2.1").with_exports("*"),
                      "file.txt": ""})
         client.run("create .")
@@ -317,7 +304,7 @@ class UploadTest(unittest.TestCase):
         assert "hello0/1.2.1" in client.out
 
     def test_upload_without_sources(self):
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         client.save({"conanfile.py": GenConanfile()})
         client.run("create . --name=pkg --version=0.1 --user=user --channel=testing")
         client.run("upload * --confirm -r default")
@@ -339,7 +326,7 @@ class UploadTest(unittest.TestCase):
         """ Without user info, uploads should fail when login prompt has been disabled.
         """
         files = {"conanfile.py": GenConanfile("hello0", "1.2.1")}
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         client.save(files)
         conan_conf = "core:non_interactive=True"
         client.save_home({"global.conf": conan_conf})
@@ -348,15 +335,15 @@ class UploadTest(unittest.TestCase):
         client.run("remote logout '*'")
         client.run("upload hello0/1.2.1@user/testing -r default", assert_error=True)
 
-        self.assertIn("Conan interactive mode disabled", client.out)
-        self.assertNotIn("-> conanmanifest.txt", client.out)
-        self.assertNotIn("-> conanfile.py", client.out)
-        self.assertNotIn("-> conan_export.tgz", client.out)
+        assert "Conan interactive mode disabled" in client.out
+        assert "-> conanmanifest.txt" not in client.out
+        assert "-> conanfile.py" not in client.out
+        assert "-> conan_export.tgz" not in client.out
 
     def test_upload_login_prompt_disabled_user_not_authenticated(self):
         # When a user is not authenticated, uploads should fail when login prompt has been disabled.
         files = {"conanfile.py": GenConanfile("hello0", "1.2.1")}
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         client.save(files)
         conan_conf = "core:non_interactive=True"
         client.save_home({"global.conf": conan_conf})
@@ -364,15 +351,15 @@ class UploadTest(unittest.TestCase):
         client.run("remote logout '*'")
         client.run("remote set-user default lasote")
         client.run("upload hello0/1.2.1@user/testing -r default", assert_error=True)
-        self.assertIn("Conan interactive mode disabled", client.out)
-        self.assertNotIn("-> conanmanifest.txt", client.out)
-        self.assertNotIn("-> conanfile.py", client.out)
-        self.assertNotIn("-> conan_export.tgz", client.out)
-        self.assertNotIn("Please enter a password for", client.out)
+        assert "Conan interactive mode disabled" in client.out
+        assert "-> conanmanifest.txt" not in client.out
+        assert "-> conanfile.py" not in client.out
+        assert "-> conan_export.tgz" not in client.out
+        assert "Please enter a password for" not in client.out
 
     def test_upload_login_prompt_disabled_user_authenticated(self):
         #  When user is authenticated, uploads should work even when login prompt has been disabled.
-        client = TestClient(default_server_user=True)
+        client = TestClient(default_server_user=True, light=True)
         client.save({"conanfile.py": GenConanfile("hello0", "1.2.1")})
         conan_conf = "core:non_interactive=True"
         client.save_home({"global.conf": conan_conf})
@@ -401,7 +388,7 @@ class UploadTest(unittest.TestCase):
         client.run("install --requires=hello0/1.2.1@user/testing -r server1")
         client.run("remote remove server1")
         client.run("upload hello0/1.2.1@user/testing -r server2")
-        self.assertNotIn("ERROR: 'server1'", client.out)
+        assert "ERROR: 'server1'" not in client.out
 
     def test_upload_without_user_channel(self):
         server = TestServer(users={"user": "password"}, write_permissions=[("*/*@*/*", "*")])
@@ -411,21 +398,21 @@ class UploadTest(unittest.TestCase):
         client.save({"conanfile.py": GenConanfile()})
 
         client.run('create . --name=lib --version=1.0')
-        self.assertIn("lib/1.0: Package '{}' created".format(NO_SETTINGS_PACKAGE_ID), client.out)
+        assert "lib/1.0: Package '{}' created".format(NO_SETTINGS_PACKAGE_ID) in client.out
         client.run('upload lib/1.0 -c -r default')
         assert "Uploading recipe 'lib/1.0" in client.out
 
         # Verify that in the remote it is stored as "_"
         pref = PkgReference.loads("lib/1.0@#0:{}#0".format(NO_SETTINGS_PACKAGE_ID))
         path = server.server_store.export(pref.ref)
-        self.assertIn("/lib/1.0/_/_/0/export", path.replace("\\", "/"))
+        assert "/lib/1.0/_/_/0/export" in path.replace("\\", "/")
 
         path = server.server_store.package(pref)
-        self.assertIn("/lib/1.0/_/_/0/package", path.replace("\\", "/"))
+        assert "/lib/1.0/_/_/0/package" in path.replace("\\", "/")
 
         # Should be possible with explicit package
         client.run(f'upload lib/1.0#*:{NO_SETTINGS_PACKAGE_ID} -c -r default --force')
-        self.assertIn("Uploading artifacts", client.out)
+        assert "Uploading artifacts" in client.out
 
     def test_upload_without_cleaned_user(self):
         """ When a user is not authenticated, uploads failed first time
@@ -488,7 +475,7 @@ def test_upload_only_without_user_channel():
     check that we can upload only the packages without user and channel
     https://github.com/conan-io/conan/issues/10579
     """
-    c = TestClient(default_server_user=True)
+    c = TestClient(default_server_user=True, light=True)
 
     c.save({"conanfile.py": GenConanfile("lib", "1.0")})
     c.run('create .')
@@ -512,7 +499,7 @@ def test_upload_only_without_user_channel():
 
 def test_upload_with_python_requires():
     # https://github.com/conan-io/conan/issues/14503
-    c = TestClient(default_server_user=True)
+    c = TestClient(default_server_user=True, light=True)
     c.save({"tool/conanfile.py": GenConanfile("tool", "0.1"),
             "dep/conanfile.py": GenConanfile("dep", "0.1").with_python_requires("tool/[>=0.1]")})
     c.run("create tool")
@@ -525,7 +512,7 @@ def test_upload_with_python_requires():
 
 
 def test_upload_list_only_recipe():
-    c = TestClient(default_server_user=True)
+    c = TestClient(default_server_user=True, light=True)
     c.save({"conanfile.py": GenConanfile("liba", "0.1")})
     c.run("create .")
     c.run("install --requires=liba/0.1 --format=json", redirect_stdout="graph.json")
@@ -534,75 +521,49 @@ def test_upload_list_only_recipe():
     assert "conan_package.tgz" not in c.out
 
 
-def test_upload_json_output():
-    c = TestClient(default_server_user=True)
+@pytest.mark.parametrize("dry_run", [True, False])
+def test_upload_json_output(dry_run):
+    c = TestClient(default_server_user=True, light=True)
     c.save({"conanfile.py": GenConanfile("liba", "0.1").with_settings("os")
                                                        .with_shared_option(False)})
     c.run("create . -s os=Linux")
-    c.run("upload * -r=default -c --format=json")
+    dry_run_arg = "--dry-run" if dry_run else ""
+    c.run(f"upload * -r=default {dry_run_arg} -c --format=json")
     list_pkgs = json.loads(c.stdout)
     revs = list_pkgs["default"]["liba/0.1"]["revisions"]["a565bd5defd3a99e157698fcc6e23b25"]
     pkg = revs["packages"]["9e0f8140f0fe6b967392f8d5da9881e232e05ff8"]
     prev = pkg["revisions"]["f50f552c6e04b1f241e5f7864bc3957f"]
     assert pkg["info"] == {"settings": {"os": "Linux"}, "options": {"shared": "False"}}
+    base_url = "v2/conans/liba/0.1/_/_/revisions/a565bd5defd3a99e157698fcc6e23b25"
     assert revs["upload-urls"] == {
         "conanfile.py": {
-            "url": f"{c.servers['default']}/v2/conans/liba/0.1/_/_/revisions/a565bd5defd3a99e157698fcc6e23b25/files/conanfile.py",
+            "url": f"{c.servers['default']}/{base_url}/files/conanfile.py",
             "checksum": sha1sum(revs["files"]["conanfile.py"])
         },
         "conanmanifest.txt": {
-            "url": f"{c.servers['default']}/v2/conans/liba/0.1/_/_/revisions/a565bd5defd3a99e157698fcc6e23b25/files/conanmanifest.txt",
+            "url": f"{c.servers['default']}/{base_url}/files/conanmanifest.txt",
             "checksum": sha1sum(revs["files"]["conanmanifest.txt"])
         }
     }
+    pkg_url = "9e0f8140f0fe6b967392f8d5da9881e232e05ff8/revisions/f50f552c6e04b1f241e5f7864bc3957f"
     assert prev["upload-urls"] == {
         "conan_package.tgz": {
-            "url": f"{c.servers['default']}/v2/conans/liba/0.1/_/_/revisions/a565bd5defd3a99e157698fcc6e23b25/packages/9e0f8140f0fe6b967392f8d5da9881e232e05ff8/revisions/f50f552c6e04b1f241e5f7864bc3957f/files/conan_package.tgz",
+            "url": f"{c.servers['default']}/{base_url}/packages/{pkg_url}/files/conan_package.tgz",
             "checksum": sha1sum(prev["files"]["conan_package.tgz"])
         },
         "conaninfo.txt": {
-            "url": f"{c.servers['default']}/v2/conans/liba/0.1/_/_/revisions/a565bd5defd3a99e157698fcc6e23b25/packages/9e0f8140f0fe6b967392f8d5da9881e232e05ff8/revisions/f50f552c6e04b1f241e5f7864bc3957f/files/conaninfo.txt",
+            "url": f"{c.servers['default']}/{base_url}/packages/{pkg_url}/files/conaninfo.txt",
             "checksum": sha1sum(prev["files"]["conaninfo.txt"])
         },
         "conanmanifest.txt": {
-            "url": f"{c.servers['default']}/v2/conans/liba/0.1/_/_/revisions/a565bd5defd3a99e157698fcc6e23b25/packages/9e0f8140f0fe6b967392f8d5da9881e232e05ff8/revisions/f50f552c6e04b1f241e5f7864bc3957f/files/conanmanifest.txt",
+            "url": f"{c.servers['default']}/{base_url}/packages/{pkg_url}/files/conanmanifest.txt",
             "checksum": sha1sum(prev["files"]["conanmanifest.txt"])
         }
     }
 
-
-def test_upload_dry_run_json_output():
-    c = TestClient(default_server_user=True)
-    c.save({"conanfile.py": GenConanfile("liba", "0.1").with_settings("os")
-                                                       .with_shared_option(False)})
-    c.run("create . -s os=Linux")
-    c.run("upload * -r=default -c --dry-run --format=json")
-    list_pkgs = json.loads(c.stdout)
-    revs = list_pkgs["default"]["liba/0.1"]["revisions"]["a565bd5defd3a99e157698fcc6e23b25"]
-    pkg = revs["packages"]["9e0f8140f0fe6b967392f8d5da9881e232e05ff8"]
-    prev = pkg["revisions"]["f50f552c6e04b1f241e5f7864bc3957f"]
-    assert pkg["info"] == {"settings": {"os": "Linux"}, "options": {"shared": "False"}}
-    assert revs["upload-urls"] == {
-        "conanfile.py": {
-            "url": f"{c.servers['default']}/v2/conans/liba/0.1/_/_/revisions/a565bd5defd3a99e157698fcc6e23b25/files/conanfile.py",
-            "checksum": sha1sum(revs["files"]["conanfile.py"])
-        },
-        "conanmanifest.txt": {
-            "url": f"{c.servers['default']}/v2/conans/liba/0.1/_/_/revisions/a565bd5defd3a99e157698fcc6e23b25/files/conanmanifest.txt",
-            "checksum": sha1sum(revs["files"]["conanmanifest.txt"])
-        }
-    }
-    assert prev["upload-urls"] == {
-        "conan_package.tgz": {
-            "url": f"{c.servers['default']}/v2/conans/liba/0.1/_/_/revisions/a565bd5defd3a99e157698fcc6e23b25/packages/9e0f8140f0fe6b967392f8d5da9881e232e05ff8/revisions/f50f552c6e04b1f241e5f7864bc3957f/files/conan_package.tgz",
-            "checksum": sha1sum(prev["files"]["conan_package.tgz"])
-        },
-        "conaninfo.txt": {
-            "url": f"{c.servers['default']}/v2/conans/liba/0.1/_/_/revisions/a565bd5defd3a99e157698fcc6e23b25/packages/9e0f8140f0fe6b967392f8d5da9881e232e05ff8/revisions/f50f552c6e04b1f241e5f7864bc3957f/files/conaninfo.txt",
-            "checksum": sha1sum(prev["files"]["conaninfo.txt"])
-        },
-        "conanmanifest.txt": {
-            "url": f"{c.servers['default']}/v2/conans/liba/0.1/_/_/revisions/a565bd5defd3a99e157698fcc6e23b25/packages/9e0f8140f0fe6b967392f8d5da9881e232e05ff8/revisions/f50f552c6e04b1f241e5f7864bc3957f/files/conanmanifest.txt",
-            "checksum": sha1sum(prev["files"]["conanmanifest.txt"])
-        }
-    }
+    if dry_run:
+        # check we don't have anything about the upload-urls in the text formatter
+        c.run("upload * -r=default -c --dry-run")
+        assert "upload-urls" not in c.out
+        assert "url:" not in c.out
+        assert "checksum:" not in c.out
