@@ -36,7 +36,7 @@ def test_legacy_names_filenames():
     for name in ["cpp_info.names", "cpp_info.filenames", "env_info", "user_info", "cpp_info.build_modules"]:
         assert f"WARN: deprecated:     '{name}' used in: pkg/1.0" in c.out
 
-    save(c.paths.new_config_path, 'core:skip_warnings=["deprecated"]')
+    c.save_home({"global.conf": 'core:skip_warnings=["deprecated"]'})
     c.run("create .")
     for name in ["cpp_info.names", "cpp_info.filenames", "env_info", "user_info",
                  "cpp_info.build_modules"]:
