@@ -1,3 +1,4 @@
+import json
 import platform
 import textwrap
 import os
@@ -339,3 +340,57 @@ def test_profile_macro_per_package():
     assert "conanfile.py (mypkg/0.1): user.conf:key=2!!!!" in client.out
     assert "conanfile.py (mypkg/0.1): os=Windows!!" in client.out
     assert "conanfile.py (mypkg/0.1): arch=x86!!" in client.out
+
+
+def test_profile_jinja_context():
+    """
+        Test the ``context=build/host`` injection
+    """
+    c = TestClient()
+    tpl1 = textwrap.dedent("""
+        [conf]
+        {% if context == "host" %}
+        user.profile:common = myhost
+        {% elif context == "build" %}
+        user.profile:common = mybuild
+        {% else %}
+        user.profile:common= nocontext
+        [settings]
+        os = Linux
+        {% endif %}
+        """)
+    tpl2 = textwrap.dedent("""
+        include(common)
+        [conf]
+        {% if context == "host" %}
+        user.profile:base = myhost
+        {% elif context == "build" %}
+        user.profile:base = mybuild
+        {% else %}
+        user.profile:base = nocontext
+        [settings]
+        arch = x86
+        {% endif %}
+        """)
+
+    c.save({"common": tpl1,
+            "base": tpl2})
+
+    c.run("profile show -pr:a=base --format=json")
+    profiles = json.loads(c.stdout)
+    assert profiles["host"]["conf"] == {"user.profile:common": "myhost",
+                                        "user.profile:base": "myhost"}
+    assert profiles["build"]["conf"] == {"user.profile:common": "mybuild",
+                                         "user.profile:base": "mybuild"}
+
+    # Now lets test when profile is neither build/host, like when used in ``conan list``
+    c.save({"conanfile.py": GenConanfile("pkg", "0.1").with_settings("os", "arch")})
+    c.run("create . -s os=Linux -s arch=x86")
+    c.run("create . -s os=Windows -s arch=armv8")
+
+    # This will pick the Linux+x86 package binary
+    c.run("list *:* --filter-profile=base")
+    assert "os: Windows" not in c.out
+    assert "arch: armv8" not in c.out
+    assert "os: Linux" in c.out
+    assert "arch: x86" in c.out
