@@ -1,5 +1,3 @@
-import unittest
-
 from mock import Mock
 
 from conan.internal.graph.graph import CONTEXT_HOST
@@ -8,7 +6,7 @@ from conan.internal.model.conan_file import ConanFile
 from conan.api.model import RecipeReference
 
 
-class DepsGraphTest(unittest.TestCase):
+class TestDepsGraph:
 
     def test_node(self):
         """ nodes are different even if contain same values,
@@ -23,7 +21,7 @@ class DepsGraphTest(unittest.TestCase):
         n1 = Node(ref1, conanfile1, context=CONTEXT_HOST)
         n2 = Node(ref2, conanfile2, context=CONTEXT_HOST)
 
-        self.assertNotEqual(n1, n2)
+        assert n1 != n2
 
     def test_basic_levels(self):
         ref1 = RecipeReference.loads("hello/1.0@user/stable")
@@ -39,7 +37,7 @@ class DepsGraphTest(unittest.TestCase):
         deps.add_node(n3)
         deps.add_edge(n1, n2, None)
         deps.add_edge(n2, n3, None)
-        self.assertEqual([[n3], [n2], [n1]], deps.by_levels())
+        assert [[n3], [n2], [n1]] == deps.by_levels()
 
     def test_multi_levels(self):
         ref1 = RecipeReference.loads("hello/1.0@user/stable")
@@ -59,7 +57,7 @@ class DepsGraphTest(unittest.TestCase):
         deps.add_edge(n1, n2, None)
         deps.add_edge(n2, n31, None)
         deps.add_edge(n2, n32, None)
-        self.assertEqual([[n31, n32], [n2], [n1]], deps.by_levels())
+        assert [[n31, n32], [n2], [n1]] == deps.by_levels()
 
     def test_multi_levels_2(self):
 
@@ -84,7 +82,7 @@ class DepsGraphTest(unittest.TestCase):
         deps.add_edge(n1, n5, None)
         deps.add_edge(n2, n31, None)
         deps.add_edge(n2, n32, None)
-        self.assertEqual([[n31, n32, n5], [n2], [n1]], deps.by_levels())
+        assert [[n31, n32, n5], [n2], [n1]] == deps.by_levels()
 
     def test_multi_levels_3(self):
 
@@ -110,4 +108,4 @@ class DepsGraphTest(unittest.TestCase):
         deps.add_edge(n2, n31, None)
         deps.add_edge(n2, n32, None)
         deps.add_edge(n32, n5, None)
-        self.assertEqual([[n31, n5], [n32], [n2], [n1]], deps.by_levels())
+        assert [[n31, n5], [n32], [n2], [n1]] == deps.by_levels()
