@@ -1,5 +1,5 @@
 import os
-import unittest
+import pytest
 
 from conan.internal.api.uploader import compress_files
 from conan.internal.paths import PACKAGE_TGZ_NAME
@@ -7,7 +7,7 @@ from conan.test.utils.test_files import temp_folder
 from conan.internal.util.files import save
 
 
-class RemoteManagerTest(unittest.TestCase):
+class TestRemoteManager:
 
     def test_compress_files(self):
         folder = temp_folder()
@@ -20,6 +20,6 @@ class RemoteManagerTest(unittest.TestCase):
         }
 
         path = compress_files(files, PACKAGE_TGZ_NAME, dest_dir=folder)
-        self.assertTrue(os.path.exists(path))
+        assert os.path.exists(path)
         expected_path = os.path.join(folder, PACKAGE_TGZ_NAME)
-        self.assertEqual(path, expected_path)
+        assert path == expected_path
