@@ -1,12 +1,11 @@
 from math import floor
 
 import time
-import unittest
 
 from conans.server.revision_list import RevisionList
 
 
-class RevisionListTest(unittest.TestCase):
+class TestRevisionList:
 
     def test_remove_latest(self):
         rev = RevisionList()
@@ -15,11 +14,11 @@ class RevisionListTest(unittest.TestCase):
 
         dumped = rev.dumps()
         loaded = RevisionList.loads(dumped)
-        self.assertEqual(rev, loaded)
-        self.assertEqual(loaded.latest_revision().revision, "rev2")
+        assert rev == loaded
+        assert loaded.latest_revision().revision == "rev2"
 
         loaded.remove_revision("rev2")
-        self.assertEqual(loaded.latest_revision().revision, "rev1")
+        assert loaded.latest_revision().revision == "rev1"
 
     def test_remove_non_latest(self):
         rev = RevisionList()
@@ -29,7 +28,7 @@ class RevisionListTest(unittest.TestCase):
         dumped = rev.dumps()
         loaded = RevisionList.loads(dumped)
         loaded.remove_revision("rev1")
-        self.assertEqual(loaded.latest_revision().revision, "rev2")
+        assert loaded.latest_revision().revision == "rev2"
 
     def test_compatibility_with_timestamps(self):
         the_time = floor(time.time())
@@ -37,4 +36,4 @@ class RevisionListTest(unittest.TestCase):
                        '{"revision": "rev2", "time": %s}]}' % (the_time, the_time)
         r_list = RevisionList.loads(old_contents)
         when = r_list.get_time("rev1")
-        self.assertEqual(when, the_time)
+        assert when == the_time
