@@ -8,12 +8,12 @@ import pytest
 from conan.errors import ConanException
 from conan.tools.env import Environment
 from conan.tools.env.environment import ProfileEnvironment
-from conans.client.subsystems import WINDOWS
+from conan.internal.subsystems import WINDOWS
 from conan.api.model import RecipeReference
 from conan.test.utils.mocks import ConanFileMock, MockSettings
 from conan.test.utils.test_files import temp_folder
 from conan.test.utils.env import environment_update
-from conans.util.files import save, chdir
+from conan.internal.util.files import save, chdir
 
 
 def test_compose():
@@ -180,7 +180,7 @@ def test_profile():
 
 
 @pytest.fixture
-def env():
+def envvars():
     # Append and define operation over the same variable in Windows preserve order
     env = Environment()
     env.define("MyVar", "MyValueA")
@@ -211,7 +211,7 @@ def check_command_output(cmd, prevenv):
 
 
 @pytest.mark.skipif(platform.system() != "Windows", reason="Requires Windows")
-def test_windows_case_insensitive_bat(env):
+def test_windows_case_insensitive_bat(envvars):
     display = textwrap.dedent("""\
         @echo off
         echo MyVar=%MyVar%!!
@@ -222,16 +222,17 @@ def test_windows_case_insensitive_bat(env):
     prevenv = {
         "MYVAR2": "OldValue2",
     }
+    prevenv.update(dict(os.environ.copy()))  # Necessary from Python 3.12, for SYSTEMROOT var
 
     with chdir(temp_folder()):
-        env.save_bat("test.bat")
+        envvars.save_bat("test.bat")
         save("display.bat", display)
         cmd = "test.bat && display.bat && deactivate_test.bat && display.bat"
         check_command_output(cmd, prevenv)
 
 
 @pytest.mark.skipif(platform.system() != "Windows", reason="Requires Windows")
-def test_windows_case_insensitive_ps1(env):
+def test_windows_case_insensitive_ps1(envvars):
     display = textwrap.dedent("""\
         echo "MyVar=$env:MyVar!!"
         echo "MyVar1=$env:MyVar1!!"
@@ -244,7 +245,7 @@ def test_windows_case_insensitive_ps1(env):
     prevenv.update(dict(os.environ.copy()))
 
     with chdir(temp_folder()):
-        env.save_ps1("test.ps1")
+        envvars.save_ps1("test.ps1")
         save("display.ps1", display)
         cmd = "powershell.exe .\\test.ps1 ; .\\display.ps1 ; .\\deactivate_test.ps1 ; .\\display.ps1"
         check_command_output(cmd, prevenv)
@@ -274,28 +275,18 @@ def test_dict_access():
     # With previous values in the environment
     env = Environment()
     env.prepend("MyVar", "MyValue", separator="@")
-    old_env = dict(os.environ)
-    os.environ.update({"MyVar": "PreviousValue"})
-    env_vars = env.vars(ConanFileMock())
-    try:
+    with environment_update({"MyVar": "PreviousValue"}):
+        env_vars = env.vars(ConanFileMock())
         assert env_vars["MyVar"] == "MyValue@PreviousValue"
-    finally:
-        os.environ.clear()
-        os.environ.update(old_env)
 
     env = Environment()
     env.append_path("MyVar", "MyValue")
-    old_env = dict(os.environ)
-    os.environ.update({"MyVar": "PreviousValue"})
-    env_vars = env.vars(ConanFileMock())
-    env_vars._subsystem = WINDOWS
-    try:
+    with environment_update({"MyVar": "PreviousValue"}):
+        env_vars = env.vars(ConanFileMock())
+        env_vars._subsystem = WINDOWS
         assert env_vars["MyVar"] == "PreviousValue;MyValue"
         with env_vars.apply():
             assert os.getenv("MyVar") == "PreviousValue;MyValue"
-    finally:
-        os.environ.clear()
-        os.environ.update(old_env)
 
     assert list(env_vars.keys()) == ["MyVar"]
     assert dict(env_vars.items()) == {"MyVar": "MyValue"}
