@@ -1,9 +1,6 @@
-import unittest
-
 import mock
 from unittest.mock import patch
 import pytest
-from parameterized import parameterized
 
 from conan.internal.api.detect.detect_api import _cc_compiler, detect_suncc_compiler, \
     detect_intel_compiler
@@ -14,14 +11,14 @@ from conan.test.utils.tools import redirect_output
 from conan.test.utils.env import environment_update
 
 
-class DetectTest(unittest.TestCase):
+class TestDetect:
     @mock.patch("platform.machine", return_value="")
     def test_detect_empty_arch(self, _):
         result = detect_defaults_settings()
         result = dict(result)
-        self.assertTrue("arch" not in result)
+        assert "arch" not in result
 
-    @parameterized.expand([
+    @pytest.mark.parametrize("processor,bitness,version,expected_arch", [
         ['powerpc', '64', '7.1.0.0', 'ppc64'],
         ['powerpc', '32', '7.1.0.0', 'ppc32'],
         ['rs6000', None, '4.2.1.0', 'ppc32']
@@ -34,10 +31,10 @@ class DetectTest(unittest.TestCase):
                 mock.patch('subprocess.check_output', mock.MagicMock(return_value=version)):
             result = detect_defaults_settings()
             result = dict(result)
-            self.assertEqual("AIX", result['os'])
-            self.assertEqual(expected_arch, result['arch'])
+            assert "AIX" == result['os']
+            assert expected_arch == result['arch']
 
-    @parameterized.expand([
+    @pytest.mark.parametrize("machine,expected_arch", [
         ['arm64', 'armv8'],
         ['i386', 'x86'],
         ['i686', 'x86'],
@@ -50,7 +47,7 @@ class DetectTest(unittest.TestCase):
         with mock.patch("platform.machine", mock.MagicMock(return_value=machine)):
             result = detect_defaults_settings()
             result = dict(result)
-            self.assertEqual(expected_arch, result['arch'])
+            assert expected_arch == result['arch']
 
     @mock.patch("conan.internal.api.detect.detect_api.detect_clang_compiler",
                 return_value=("clang", Version("9"), "clang"))
@@ -59,21 +56,30 @@ class DetectTest(unittest.TestCase):
         with redirect_output(output):
             with environment_update({"CC": "clang-9 --gcc-toolchain=/usr/lib/gcc/x86_64-linux-gnu/9"}):
                 detect_defaults_settings()
-                self.assertIn("CC and CXX: clang-9 --gcc-toolchain", output)
+                assert "CC and CXX: clang-9 --gcc-toolchain" in output
 
 
 @pytest.mark.parametrize("version_return,expected_version", [
     ["cc.exe (Rev3, Built by MSYS2 project) 14.1.0", "14.1.0"],
     ["g++ (Conan-Build-gcc--binutils-2.42) 14.1.0", "14.1.0"],
+    ["gcc.exe (x86_64-posix-seh-rev0, Built by MinGW-Builds project) 15.1.0", "15.1.0"],
+    ["gcc.exe (x86_64-posix-seh-rev0, Built by MinGW-Builds project) 15.15.0", "15.15.0"],
+    ["gcc (crosstool-NG 1.27.0) 13.3.0", "13.3.0"],
+    ["gcc (crosstool-NG 1.27.0) 13.3", "13.3"],
+    ["gcc (GCC) 4.8.1", "4.8.1"],
     ["clang version 18.1.0rc (https://github.com/llvm/llvm-project.git 461274b81d8641eab64d494accddc81d7db8a09e)", "18.1.0"],
     ["cc.exe (Rev3, Built by MSYS2 project) 14.0", "14.0"],
     ["clang version 18 (https://github.com/llvm/llvm-project.git 461274b81d8641eab64d494accddc81d7db8a09e)", "18"],
     ["cc.exe (Rev3, Built by MSYS2 project) 14", "14"],
+    ["cc.exe 14.2", "14.2"],
+    ["cc1 14.2", "14.2"],
 ])
 @patch("conan.internal.api.detect.detect_api.detect_runner")
-def test_detect_cc_versionings(detect_runner_mock, version_return, expected_version):
+def test_detect_cc_versioning(detect_runner_mock, version_return, expected_version):
     detect_runner_mock.return_value = 0, version_return
     compiler, installed_version, compiler_exe = _cc_compiler()
+    # Using private _value attribute to compare the str that reaches it, so no space issues arise
+    assert installed_version._value == Version(expected_version)._value
     assert installed_version == Version(expected_version)
 
 @pytest.mark.parametrize("function,version_return,expected_version", [
