@@ -1,9 +1,13 @@
 import os
+import platform
 import tarfile
-import unittest
 import zipfile
 
+import pytest
+import sys
+
 from conan.internal.api.uploader import gzopen_without_timestamps
+from conan.tools.files import load
 from conan.tools.files.files import untargz, unzip
 from conan.errors import ConanException
 from conan.internal.model.manifest import gather_files
@@ -15,7 +19,7 @@ from conan.internal.util.files import chdir, save
 from conan.internal.util.files import rmdir
 
 
-class ZipExtractPlainTest(unittest.TestCase):
+class TestZipExtractPlain:
 
     def _zipdir(self, path, zipfilename, folder_entry=None):
         with zipfile.ZipFile(zipfilename, 'w', zipfile.ZIP_DEFLATED) as z:
@@ -52,23 +56,23 @@ class ZipExtractPlainTest(unittest.TestCase):
         output = RedirectedTestOutput()
         with redirect_output(output):
             unzip(ConanFileMock(), zip_file, destination=extract_folder, strip_root=False)
-        self.assertNotIn("ERROR: Error extract", output)
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "file1")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "folder",
-                                                    "file2")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "file3")))
+        assert "ERROR: Error extract" not in output
+        assert os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3"))
+        assert os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "file1"))
+        assert os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "folder",
+                                           "file2"))
+        assert os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "file3"))
 
         # Extract without the subfolder
         extract_folder = temp_folder()
         output = RedirectedTestOutput()
         with redirect_output(output):
             unzip(ConanFileMock(), zip_file, destination=extract_folder, strip_root=True)
-        self.assertNotIn("ERROR: Error extract", output)
-        self.assertFalse(os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "file1")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "folder", "file2")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "file3")))
+        assert "ERROR: Error extract" not in output
+        assert not os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3"))
+        assert os.path.exists(os.path.join(extract_folder, "file1"))
+        assert os.path.exists(os.path.join(extract_folder, "folder", "file2"))
+        assert os.path.exists(os.path.join(extract_folder, "file3"))
 
     def test_invalid_flat(self):
         tmp_folder = temp_folder()
@@ -86,9 +90,11 @@ class ZipExtractPlainTest(unittest.TestCase):
 
         # Extract without the subfolder
         extract_folder = temp_folder()
-        with self.assertRaisesRegex(ConanException, "The zip file contains more than 1 folder "
-                                                         "in the root"):
+        try:
             unzip(ConanFileMock(), zip_file, destination=extract_folder, strip_root=True)
+            assert False, "Expected ConanException"
+        except ConanException as e:
+            assert "The zip file contains more than 1 folder in the root" in str(e)
 
     def test_invalid_flat_single_file(self):
         tmp_folder = temp_folder()
@@ -101,11 +107,14 @@ class ZipExtractPlainTest(unittest.TestCase):
 
         # Extract without the subfolder
         extract_folder = temp_folder()
-        with self.assertRaisesRegex(ConanException, "The zip file contains a file in the root"):
+        try:
             unzip(ConanFileMock(), zip_file, destination=extract_folder, strip_root=True)
+            assert False, "Expected ConanException"
+        except ConanException as e:
+            assert "The zip file contains a file in the root" in str(e)
 
 
-class TarExtractPlainTest(unittest.TestCase):
+class TestTarExtractPlain:
 
     def _compress_folder(self, folder, tgz_path, folder_entry=None):
         # Create a tar.gz file with the files in the folder and an additional TarInfo entry
@@ -186,19 +195,19 @@ class TarExtractPlainTest(unittest.TestCase):
         # Tgz unzipped regularly
         extract_folder = temp_folder()
         untargz(tgz_file, destination=extract_folder, strip_root=False)
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "file1")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "folder",
-                                                    "file2")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "file3")))
+        assert os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3"))
+        assert os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "file1"))
+        assert os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "folder",
+                                           "file2"))
+        assert os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3", "file3"))
 
         # Extract without the subfolder
         extract_folder = temp_folder()
         untargz(tgz_file, destination=extract_folder, strip_root=True)
-        self.assertFalse(os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "file1")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "folder", "file2")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "file3")))
+        assert not os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3"))
+        assert os.path.exists(os.path.join(extract_folder, "file1"))
+        assert os.path.exists(os.path.join(extract_folder, "folder", "file2"))
+        assert os.path.exists(os.path.join(extract_folder, "file3"))
 
     def test_plain_tgz_common_base(self):
 
@@ -221,10 +230,10 @@ class TarExtractPlainTest(unittest.TestCase):
         # Tgz unzipped regularly
         extract_folder = temp_folder()
         untargz(tgz_file, destination=extract_folder, strip_root=True)
-        self.assertFalse(os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "folder", "file1")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "folder", "file2")))
-        self.assertTrue(os.path.exists(os.path.join(extract_folder, "folder", "file3")))
+        assert not os.path.exists(os.path.join(extract_folder, "subfolder-1.2.3"))
+        assert os.path.exists(os.path.join(extract_folder, "folder", "file1"))
+        assert os.path.exists(os.path.join(extract_folder, "folder", "file2"))
+        assert os.path.exists(os.path.join(extract_folder, "folder", "file3"))
 
     def test_invalid_flat(self):
         tmp_folder = temp_folder()
@@ -241,9 +250,11 @@ class TarExtractPlainTest(unittest.TestCase):
         self._compress_folder(tmp_folder, tgz_file)
 
         extract_folder = temp_folder()
-        with self.assertRaisesRegex(ConanException, "The tgz file contains more than 1 folder "
-                                                         "in the root"):
+        try:
             untargz(tgz_file, destination=extract_folder, strip_root=True)
+            assert False, "Expected ConanException"
+        except ConanException as e:
+            assert "The tgz file contains more than 1 folder in the root" in str(e)
 
     def test_invalid_flat_single_file(self):
         tmp_folder = temp_folder()
@@ -256,8 +267,11 @@ class TarExtractPlainTest(unittest.TestCase):
 
         # Extract without the subfolder
         extract_folder = temp_folder()
-        with self.assertRaisesRegex(ConanException, "Can't untar a tgz containing files in the root with strip_root enabled"):
+        try:
             unzip(ConanFileMock(), tgz_file, destination=extract_folder, strip_root=True)
+            assert False, "Expected ConanException"
+        except ConanException as e:
+            assert "Can't untar a tgz containing files in the root with strip_root enabled" in str(e)
 
     def test_invalid_flat_multiple_file(self):
         tmp_folder = temp_folder()
@@ -271,8 +285,11 @@ class TarExtractPlainTest(unittest.TestCase):
 
         # Extract without the subfolder
         extract_folder = temp_folder()
-        with self.assertRaisesRegex(ConanException, "Can't untar a tgz containing files in the root with strip_root enabled"):
+        try:
             unzip(ConanFileMock(), tgz_file, destination=extract_folder, strip_root=True)
+            assert False, "Expected ConanException"
+        except ConanException as e:
+            assert "Can't untar a tgz containing files in the root with strip_root enabled" in str(e)
 
 
 def _compress_root_folder(folder, tgz_path, root_folder_name="root"):
@@ -314,3 +331,31 @@ def test_decompressing_folders_with_different_modes():
     extract_folder = temp_folder()
     # Do not raise any PermissionError
     untargz(tgz_file, destination=extract_folder, strip_root=True)
+
+
+@pytest.mark.skipif(sys.version_info < (3, 13, 4), reason="requires Python 3.13.4 or higher")
+@pytest.mark.skipif(platform.system() != "Windows", reason="Requires Windows")
+def test_decompressing_using_long_path_prefix():
+    """
+    If we use the "\\?\" prefix, untar() function should not
+    raise an OSError: [WinError 123] error.
+
+    Issue related: https://github.com/conan-io/conan/issues/18574
+    """
+    tmp_folder = temp_folder()
+    tgz_folder = temp_folder()
+    tgz_file = os.path.join(tgz_folder, "file.tar.gz")
+    with chdir(tmp_folder):
+        save("root/parent/bin/file1", "contentsfile1")
+        save("root/parent/bin/file2", "contentsfile2")
+        _compress_root_folder(tmp_folder, tgz_file, root_folder_name="root")
+
+    # Tgz unzipped regularly
+    extract_folder = f"\\\\?\\{temp_folder()}"
+    # Do not raise any OSError: [WinError 123]
+    untargz(tgz_file, destination=extract_folder, strip_root=True)
+    assert "contentsfile1" in load(ConanFileMock(), os.path.join(extract_folder, "parent", "bin", "file1"))
+    assert "contentsfile2" in load(ConanFileMock(), os.path.join(extract_folder, "parent", "bin", "file2"))
+    untargz(tgz_file, destination=extract_folder, strip_root=False)
+    assert "contentsfile1" in load(ConanFileMock(), os.path.join(extract_folder, "root", "parent", "bin", "file1"))
+    assert "contentsfile2" in load(ConanFileMock(), os.path.join(extract_folder, "root", "parent", "bin", "file2"))
